/**
 * 通知逻辑
 */

import axios from 'axios';
import { Injectable } from '@nestjs/common';
import { EChangeType, IRecordInfo } from './interface';

@Injectable()
export class NotifyService {
  private _itemTemplate = '[channel][uids]等玩家的[itemId][type量]已超过预警值，请注意处理';
  private _rechargeTemplate = '[channel][uids]等玩家的充值已超过预警值，请注意处理';

  async notifyXianYu(data: IRecordInfo[], channel: string, type: EChangeType) {
    if (data.length === 0) return;

    const uids = data.map(d => d.uid).join(',');
    const content = this.formatItem(channel, uids, '仙玉', type);
    console.log(content, data);
    await this.sendDD(content);
  }
  async notifyItem(data: IRecordInfo[], channel: string, itemId: number, type: EChangeType) {
    if (data.length === 0) return;

    const uids = data.map(d => d.uid).join(',');
    const content = this.formatItem(channel, uids, itemId, type);
    console.log(content, data);
    await this.sendDD(content);
  }

  async notifyRecharge(data: IRecordInfo[], channel: string) {
    if (data.length === 0) return;

    const uids = data.map(d => d.uid).join(',');
    const content = this.formatRecharge(channel, uids);
    console.log(content, data);
    await this.sendDD(content);
  }

  private formatItem(channel: string, uids: string, itemId: string | number, type: EChangeType) {
    return this._itemTemplate
      .replace('channel', channel)
      .replace('uids', uids)
      .replace('itemId', itemId as string)
      .replace('type', type === 'use' ? '消耗' : '获取')
  }
  private formatRecharge(channel: string, uids: string) {
    return this._rechargeTemplate
      .replace('channel', channel)
      .replace('uids', uids);
  }

  private async sendDD(content: string) {
    const url = 'https://oapi.dingtalk.com/robot/send?access_token=078c25a07c51570684c833d10cc04cfadf147ef6d9d2fc382d04f28e1271664e';
    const { data } = await axios.post(url, {
      msgtype: 'text',
      text: {
        content
      }
    });
    console.log('sendDd res', data);
  }
}
